@@ -31,6 +31,7 @@ OC.L10N.register(
     "How many redirects the feed fetcher should follow." : "Koliko preusmjeravanja bi hvatač sažetaka trebao pratiti.",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimalni broj sekundi koliko se čeka učitavanje RSS i Atom sažetaka; ako učitavanje duže traje, nadogradnja se prekida.",
     "Interval in seconds in which the feeds will be updated." : "Interval u sekundama u kojem će se sažeci ažurirati.",
+    "Show all articles" : "Prikaži sve članke",
     "Move" : "Premjesti",
     "Share" : "Dijeli",
     "Default" : "Zadani",
@@ -42,7 +43,6 @@ OC.L10N.register(
     "Documentation" : "Dokumentacija",
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Disable mark read through scrolling" : "Onemogući označavanje kao pročitano pri pomicanju",
-    "Show all articles" : "Prikaži sve članke",
     "Reverse ordering (oldest on top)" : "Obrnuti poredak (prvo najstariji)",
     "Rename" : "Preimenuj",
     "Delete" : "Izbriši",
@@ -54,8 +54,6 @@ OC.L10N.register(
     "Default order" : "Zadani poredak",
     "Enable full text" : "Omogući cijeli tekst",
     "Disable full text" : "Onemogući cijeli tekst",
-    "Previous" : "Natrag",
-    "Next" : "Dalje",
     "Toggle star article" : "Postavi/ukloni zvjezdicu s članka",
     "Mark unread" : "Označi kao nepročitano",
     "Close details" : "Zatvori pojedinosti",
