@@ -36,6 +36,7 @@ OC.L10N.register(
     "Article list" : "Straipsnių sąrašas",
     "Article details" : "Išsamiau apie straipsnį",
     "Please select an article from the list..." : "Pasirinkite straipsnį iš sąrašo...",
+    "Show all articles" : "Rodyti visus straipsnius",
     "Move" : "Perkelti",
     "User Name" : "Naudotojo vardas",
     "Share" : "Bendrinti",
@@ -51,7 +52,6 @@ OC.L10N.register(
     "Settings" : "Nustatymai",
     "Documentation" : "Dokumentacija",
     "Keyboard shortcuts" : "Klavišų kombinacijos",
-    "Show all articles" : "Rodyti visus straipsnius",
     "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
     "Disable automatic refresh" : "Išjungti automatinį įkėlimą iš naujo",
     "Rename" : "Pervadinti",
@@ -66,9 +66,7 @@ OC.L10N.register(
     "Enable full text" : "Įjungti raiškųjį tekstą",
     "Disable full text" : "Išjungti raiškųjį tekstą",
     "Previous Item" : "Ankstesnis elementas",
-    "Previous" : "Ankstesnis",
     "Next Item" : "Kitas elementas",
-    "Next" : "Kitas",
     "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
     "Mark unread" : "Žymėti kaip neskaitytą",
     "Close details" : "Užverti išsamesnę informaciją",
