@@ -1,9 +1,8 @@
 OC.L10N.register(
     "news",
     {
-    "Request failed, network connection unavailable!" : "Request failed, network connection unavailable!",
-    "Download" : "Download",
-    "Close" : "Close",
+    "Download" : "Yuklab olish",
+    "Close" : "Yopish",
     "Folder name" : "Folder name",
     "Username" : "Username",
     "Password" : "Password",
@@ -12,21 +11,15 @@ OC.L10N.register(
     "Subscribe" : "Obuna boʻlish",
     "Move" : "Move",
     "Share" : "Ulashish",
-    "Settings" : "Settings",
+    "Off" : "Oʻchirilgan",
+    "Settings" : "Sozlamalar",
     "Documentation" : "Hujjatlar",
-    "Rename" : "Rename",
-    "Delete" : "Delete",
-    "Previous" : "Oldingi",
+    "Rename" : "Nomini o'zgartirish",
+    "Delete" : "O'chirish",
     "Not available" : "Mavjud emas",
     "Title" : "Sarlavha",
     "right" : "right",
     "left" : "left",
-    "Refresh" : "Refresh",
-    "Description" : "Tavsif",
-    "Create" : "Yaratish",
-    "Dismiss" : "Dismiss",
-    "Import" : "Import",
-    "Export" : "Eksport",
-    "Help" : "Help"
+    "Refresh" : "Refresh"
 },
 "nplurals=1; plural=0;");
